@@ -1,6 +1,6 @@
 package Package::Pkg;
 BEGIN {
-  $Package::Pkg::VERSION = '0.0015';
+  $Package::Pkg::VERSION = '0.0016';
 }
 # ABSTRACT: Handy package munging utilities
 
@@ -8,7 +8,7 @@ BEGIN {
 use strict;
 use warnings;
 
-require Class::MOP;
+require Mouse::Util;
 require Sub::Install;
 use Try::Tiny;
 use Carp;
@@ -41,7 +41,7 @@ sub load_name {
     return $package;
 }
 
-sub _is_package_loaded ($) { return Class::MOP::is_class_loaded( $_[0] ) }
+sub _is_package_loaded ($) { return Mouse::Util::is_class_loaded( $_[0] ) }
 
 sub _package2pm ($) {
     my $package = shift;
@@ -60,7 +60,7 @@ sub loader {
 sub load {
     my $self = shift;
     my $package = @_ > 1 ? $self->name( @_ ) : $_[0];
-    return Class::MOP::load_class( $package );
+    return Mouse::Util::load_class( $package );
 }
 
 sub softload {
@@ -224,7 +224,7 @@ Package::Pkg - Handy package munging utilities
 
 =head1 VERSION
 
-version 0.0015
+version 0.0016
 
 =head1 SYNOPSIS
 
@@ -303,8 +303,6 @@ L<Sub::Install>
 
 L<Sub::Exporter>
 
-L<Class::MOP>
-
 =head1 AUTHOR
 
   Robert Krimen <robertkrimen@gmail.com>
